@@ -63,6 +63,8 @@ public:
     virtual void receive_notification(const notification &note);
 
     const video_output_qt *get_video_output() const;
+    video_output_qt *get_video_output();
+    bool is_playing() const;
     bool playloop_step();
     void force_stop();
     void move_event();
