@@ -124,7 +124,7 @@ protected:
 
 public:
     /* Constructor, Destructor */
-    video_output(bool receive_notifications = true);
+    video_output();
     virtual ~video_output();
 
     /* Initialize the video output, or throw an exception */
@@ -148,6 +148,7 @@ public:
     virtual int height() = 0;                   // in pixels
     virtual int pos_x() = 0;                    // in pixels
     virtual int pos_y() = 0;                    // in pixels
+    virtual bool fullscreen() = 0;              // whether the video area is in fullscreen mode
 
     /* Center video area on screen */
     virtual void center() = 0;
