@@ -54,6 +54,8 @@ protected:
     virtual void moveEvent(QMoveEvent *event);
     virtual void keyPressEvent(QKeyEvent *event);
     virtual void mouseReleaseEvent(QMouseEvent *event);
+    virtual void mouseDoubleClickEvent(QMouseEvent *event);
+    virtual void focusOutEvent(QFocusEvent *event);
 };
 
 /* Public interface. You can use this as a video container widget, to
@@ -91,6 +93,7 @@ private:
 
     void create_widget();
     void mouse_set_pos(float dest);
+    void mouse_toggle_fullscreen();
 
 protected:
     virtual void make_context_current();
@@ -114,6 +117,9 @@ public:
      * (even-odd-*, checkerboard). */
     void move_event();
 
+    /* Grab the keyboard focus for the video widget, to enable keyboard shortcuts */
+    void grab_focus();
+
     virtual void init();
     virtual void deinit();
 
@@ -125,11 +131,12 @@ public:
     virtual int height();
     virtual int pos_x();
     virtual int pos_y();
+    virtual bool fullscreen();
 
     virtual void center();
-    virtual void enter_fullscreen(int screen);
+    virtual void enter_fullscreen(int screens);
     virtual void exit_fullscreen();
-    virtual bool toggle_fullscreen(int screen);
+    virtual bool toggle_fullscreen(int screens);
 
     virtual void process_events();
 
